@@ -4,7 +4,4 @@ readout layers
 from .set2set import Set2Set
 from .linear import LinearWithIndex
 
-__all__ = [
-    "Set2Set",
-    "LinearWithIndex"
-]
+__all__ = ["Set2Set", "LinearWithIndex"]
